!**************************************************************************************************
! Pre-simulation procedure; initialization valuables
!**************************************************************************************************
SUBROUTINE init_value (W_sat, tmp_air, tmp_soil, prec)

!_____________ Set variables
!Namespace
   USE data_structure
   USE vegi_status_current1
   USE vegi_status_record
   USE grid_status_current1
   USE grid_status_record
   implicit none
   
!Augments
   real               ,intent(IN)::W_sat     !saturate point   (m3/m3, 0.0 -> 1.0)
   real,dimension(365),intent(IN)::tmp_air   !2m air temperature (Celcius)
   real,dimension(365),intent(IN)::tmp_soil  !soil temperature (Celcius)
   real,dimension(365),intent(IN)::prec      !precipitation (mm day-1)
   
!Local variables
   integer i
   real    x
   
!________ Initialize vegi_status_current1
!Nitrogen cotents per biomass for each PFT (gN / gBiomass)
   do i = 1, PFT_no
      PN_s(i) = 0.145 * PN_f(i) !@sapwood
      PN_r(i) = 0.86  * PN_f(i) !@root
      
!      if (Life_type(i)==1) PN_r(i)=0.25 * PN_f(i) !for Tropical evergreen trees
      if (Life_type(i)==2) PN_s(i)=0.0014         !for boreal summergreen needle leaf trees
      
   end do
   
!PFT number of C3 and C4 grass
   do i=1, PFT_no
     if (Life_type(i)==3) C3g_no = i
     if (Life_type(i)==4) C4g_no = i
   end do
   
!Variables about whole vegetation
   biome = 17 !biome type (17->desert)
   type_grass           = 3
   canopy_cond  = 0.0
   patch_vacant(:,:) = .false.
   
!Status of woody PFT (for each individual tree)
   tree_exist(:)         = .false. 
   pft(:)                = 0
   age(:)                = 0
   height(:)             = 0
   bole(:)               = 0
   dbh_heartwood(:)      = 0.0
   dbh_sapwood(:)        = 0.0
   crown_diameter(:)     = 0.0
   crown_area(:)         = 0.0
   crown_x(:)            = 0.0
   crown_y(:)            = 0.0
   bole_x(:)             = 0.0
   bole_y(:)             = 0.0
   height_limit(:)       = 0
   radius_limit(:)       = 0.0
   la(:)                 = 0.0
   mass_leaf(:)          = 0.0
   mass_trunk(:)         = 0.0
   mass_root(:)          = 0.0
   mass_stock(:)         = 0.0
   mass_available(:)     = 0.0
   stat_leaf(:)          = 0.0
   stat_leaf_crowntop(:) = 0.0
   stat_leaf_crownbottom = 0.0
   mort_regu1(:)         = 0.0
   mort_regu2(:)         = 0.0
   mort_regu4(:)         = 0.0
   par_direct_rel(:,:)   = 0.0
   
!Status of grass PFT (Biomass density approach)
   gmass_leaf(:)      = 0.0
   gmass_root(:)      = 0.0
   gmass_available(:) = 0.0
   gmass_stock(:)     = 50.0
   lai_grass(1)       = gmass_leaf(1) * SLA(C3g_no)
   lai_grass(2)       = gmass_leaf(2) * SLA(C4g_no)
   lai_opt_grass(:)   = 0.0
   
!Turn on phenology switch for evergreen trees and grasses
   do i=1, PFT_no
      if (Phenology_type(i)==0 .or. Life_type(i)==3 .or. Life_type(i)==4) then
         phenology(i) =.true.
      else
         phenology(i) =.false.
      endif
   end do
   pheno_clo(:)  = 1
   pheno_cls(:)  = 1
   
   stat_water(:)                 = 0.0
   
   pft_exist(:)     = .false.
   pft_exist(C3g_no) = .true.
   pft_exist(C4g_no) = .true.
   
!________ Initialize vegi_status_record
   lai_max_wood   = 0.0 !Wood  LAI @ annual maximum (reset@doy1) (m2/m2)
   lai_max_grass  = 0.0  !Grass LAI @ annual maximum (reset@doy1) (m2/m2)
   lai_mean_wood  = 0.0  !Wood  LAI @ annual mean    (reset@doy1) (m2/m2)
   lai_mean_grass = 0.0 !Grass LAI @ annual mean    (reset@doy1) (m2/m2)
   
   gpp(:)           = 1.0
   npp(:)           = 1.0
   gpp_month(:)     = 1.0
   npp_month(:)     = 1.0
   gpp_annual(:)    = 1.0
   npp_annual(:)    = 1.0
   gpp_month_ind(:) = 1.0
   npp_10d_ave      = 1.0
   
   do i=1, PFT_no
      phenology_RunningRecord(i,:) =phenology(i)
   end do
   
   lai_opt_grass_RunningRecord(:,:) = 0.0
   npp_RunningRecord          (:,:) = 1.0
   stat_water_RunningRecord   (:,:) = 0.0
   
!________ Initialize grid_status_current1
   gdd0         = 0.0
   gdd5         = 0.0
   
!Soil water conditions
   x = 1.0 !initialize value of moisture per water holding capacity
   pool_w(:) = x * W_sat * Depth
   pool_snow = 0.000
   
   pool_litter   = 1.0 * Max_loc * Max_loc
   pool_som_int  = 1.0 * Max_loc * Max_loc
   pool_som_slow = 1.0 * Max_loc * Max_loc
   
!________ Initialize grid_status_record
   c_emission   = 0.0
   c_uptake     = 0.0
   fire_clo     = 0  
   
   tmp_soil_month_ave  = sum(tmp_soil(336:365)) / 30.0
   tmp_coldest_20yr_ave = 0.0
   tmp_hottest_20yr_ave = 0.0
   
   gdd_20yr_ave = 0.0
   do i = 1, 365
      gdd_20yr_ave = gdd_20yr_ave + max(0.0, tmp_air(i)-5.0)
   end do
   
   hyd_ro_RunningRecord(:) = 0.0
   hyd_ic_RunningRecord(:) = 0.0
   hyd_ev_RunningRecord(:) = 0.0
   hyd_tr_RunningRecord(:) = 0.0
   
   pool_w1_RunningRecord(:) = pool_w(1)
   
   do i = 1, 365
   tmp_air_RunningRecord (i) = tmp_air (i)
   tmp_soil_RunningRecord(i) = tmp_soil(i)
   prec_RunningRecord    (i) = prec    (i)
   end do
   
   gdd_20yr_RunningRecord        (:) = gdd_20yr_ave
   par_RunningRecord             (:) = 0.0
   par_grass_RunningRecord       (:) = 0.0
   tmp_coldest_RunningRecord     (:) = 0.0
   tmp_hottest_RunningRecord     (:) = 0.0
   tmp_ave_C3growth_RunningRecord(:) = Topt0(C3g_no)
   tmp_ave_C4growth_RunningRecord(:) = Topt0(C4g_no)
   
END SUBROUTINE init_value
