!*************************************************************************************************
! Output for Viewer
!*************************************************************************************************
SUBROUTINE output_for_viewer &
   (Fn, LAT, LON, ALT, Albedo_soil0, W_fi, W_wilt, W_sat, W_mat, &
   tmp_air, tmp_soil, cloud, prec, humid, wind)

!_____________ Set variables
!Namespace
   USE data_structure
   USE time_counter
   USE vegi_status_current1
   USE vegi_status_current2
   USE vegi_status_record
   USE grid_status_current1
   USE grid_status_current2
   USE grid_status_record
   implicit none
   
!Arguments
   !File I/O number
   integer,intent(IN)::Fn
   
   !Location data (single precision)
   real,intent(IN)::LAT          !latitude  (degree)
   real,intent(IN)::LON          !longitude  (degree)
   real,intent(IN)::ALT          !altitude  (m above MSL)
   real,intent(IN)::Albedo_soil0 !soil albedo
   real,intent(IN)::W_fi         !filed capacity  (m3/m3, 0.0 -> 1.0)
   real,intent(IN)::W_wilt       !wilting point   (m3/m3, 0.0 -> 1.0)
   real,intent(IN)::W_sat        !saturate point  (m3/m3, 0.0 -> 1.0)
   real,intent(IN)::W_mat        !matrix potential
   
   !Climatic data (single precision)
   real,intent(IN)::tmp_air  !2m air temperature              (Celcius) 
   real,intent(IN)::tmp_soil !soil temperature at 10 cm depth (Celcius) 
   real,intent(IN)::cloud    !total cloudiness                (fraction)
   real,intent(IN)::prec     !precipitation                   (mm day-1)
   real,intent(IN)::humid    !specific humidity               (kg kg-1) 
   real,intent(IN)::wind     !wind velocity                   (m s-1)   
   
!Local variables
   !character(len=3)                  PFT_no_string
   real   ,dimension(PFT_no)       ::lai, tmp0, tmp1, tmp2, tmp3
   real   ,dimension(PFT_no)       ::c_leaf, c_trunk, c_root, c_stock, c_available
   integer,dimension(PFT_no,0:41)::size_dist
   
   integer i, j, k, p, no
   real    a1, a2, a3, b1, b2, b3, c1, c2, x
   real    tree_density, Dist_step
   
!_____________ Define local parameter
Dist_step = 2.5  !D.B.H. size step for size class output

!_____________ Write File header
If ( counter==1 .or.  (Flag_spinup_read .and. counter==1+Spinup_year*365) ) then
   
   !prepare strings for maximum PFT number
!   i = int(  PFT_no / 100      ) ; PFT_no_string(1:1)=char(i+48)
!   j = int( (PFT_no-i*100)/10  ) ; PFT_no_string(2:2)=char(j+48)
!   k = int(  PFT_no-i*100-j*10 ) ; PFT_no_string(3:3)=char(k+48)
   
   !write out setting
   a1 =  500.0
   a2 = 1000.0
   a3 = 1500.0
   write (Fn, '( 3(f7.2,a), i5, a, i5, 3(a,f8.1), a,i4 )' )  &
   LAT,',',LON,',',ALT,',',Simulation_year,',',PFT_no,',',a1,',',a2,',',a3,',',Max_loc
   
   write (Fn, '( f7.5,a,f7.5,a,f7.5,a,f7.5,a,f7.5 )' ) &
   Albedo_soil0,',',W_fi,',',W_wilt,',',W_sat,',',W_mat
   
   do p=1, PFT_no; write (Fn,'(i1,a$)'  ) Life_type(p),     ','; end do
   write (Fn,*)
   
   do p=1, PFT_no; write (Fn,'(i1,a$)'  ) Phenology_type(p),','; end do
   write (Fn,*)
   
   do p=1, PFT_no; write (Fn,'(f6.4,a$)') PN_s(p),          ','; end do
   write (Fn,*)
   
   do p=1, PFT_no; write (Fn,'(f6.4,a$)') PN_r(p),          ','; end do
   write (Fn,*)
   
Endif

!_____________ Write Annual output
If ( doy==1 ) then
   
   write (Fn,*)
   do p=1, PFT_no
      i = 0
      if (pft_exist(p)) i=1
      write (Fn,'(i1,a$)' ) i,','
   end do
   write (Fn,*)
   write (Fn,*)
   
Endif

!_____________ Write Daily output
!*** 1st line (Simulation day counter)
   write (Fn,'(i7)') &
   counter

!*** 2nd line (Climatic data)
   write (Fn,'( 2(f5.1,a), f5.2,a, f6.2,a, f6.3,a, f5.2 )') &
   tmp_air,',',tmp_soil,',',cloud,',',prec,',',humid,',',wind

!*** 3rd line (Physical status of air)
   write (Fn,'( f6.1,a, 2(f8.3,a), f6.3,a, f6.3 )') &
   ap,',',vp_sat,',',vp,',',dnsa,',',slope_vps

!*** 4th (Radiation properties on vegetation surface)
   write (Fn,'( 4(f4.2,a) )') &
   albedo_soil,',',albedo_veg,',',ir_tree,',',ir_grass

!*** 5th line (Physical status of radiation)
   write (Fn,'( f6.1,a, f6.1,a, f6.1,a, f6.1,a, f6.1,a, f6.1 )') &
   par_direct,',',par_diffuse,',',par_grass,',',rad,',',radnet_soil,',',radnet_veg

!*** 6th line (Hydrogical varibales)
   write (Fn,'( f7.2, 3(a,f6.1), a,f8.1 )') &
   canopy_cond,',',sum(pool_w(1:5)),',',sum(pool_w(6:15)),',',sum(pool_w(16:30)),',',pool_snow
   
!*** 7th~ lines (PFT specific variables)
   !LAI of Woody PFTs
   lai(:) = 0.0
   Do no=1, Max_no
      if ( .not. tree_exist(no) ) cycle
      p = pft(no)
      lai(p) = lai(p) + la(no)
   End do
   lai(:) = lai(:) / Max_loc / Max_loc
   
   !LAI of Grass PFTs
   if (type_grass ==3) then
      lai(C3g_no) = lai_grass(1) * 0.9
      lai(C4g_no) = lai_grass(2) * 0.1
   else
      lai(C3g_no) = lai_grass(1) * 0.1
      lai(C4g_no) = lai_grass(2) * 0.9
   endif
   
   !Write each PFT data
   tmp0(:)=0.0 ; tmp1(:)=0.0 ; tmp2(:)=0.0 ; tmp3(:)=0.0
   Do no=1, Max_no
      if ( .not. tree_exist(no)     ) cycle
      if ( .not. phenology(pft(no)) ) cycle
      if ( la(no) <=0.0             ) cycle
      
      p = pft(no)
      tmp0(p) = tmp0(p) + 1
      tmp1(p) = tmp1(p) + lue   (no)
      tmp2(p) = tmp2(p) + co2cmp(no)
      tmp3(p) = tmp3(p) + psat  (no)
   End do
   
   Do p=1, PFT_no
      tmp1(p) = tmp1(p) / Max(1.0, tmp0(p))
      tmp2(p) = tmp2(p) / Max(1.0, tmp0(p))
      tmp3(p) = tmp3(p) / Max(1.0, tmp0(p))
   End do
   
   tmp1(C3g_no) = lue_grass   (1) ; tmp1(C4g_no) = lue_grass   (2)   
   tmp2(C3g_no) = co2cmp_grass(1) ; tmp2(C4g_no) = co2cmp_grass(2)
   tmp3(C3g_no) = psat_grass  (1) ; tmp3(C4g_no) = psat_grass  (2)
   
   Do p=1, PFT_no
   if (pft_exist(p)) then
      write (Fn,'( f5.2, a, f6.3, a, f7.3, a, f4.1 )') &
      lai(p),',',tmp1(p),',',tmp2(p),',',tmp3(p)
   endif
   End do
   
!_____________ Write Monthly output
IF ( Day_of_Month(doy) == Day_in_month(Month(doy)) ) then
   
!*** 1st line
   !prepare tree density (N/ha)
   i = 0
   do no=1, Max_no
      if ( tree_exist(no) ) i = i + 1
   end do
   tree_density = real(i) * ( (100.0/Max_loc)**2 )
   
   write (Fn, '(i5, a, i2, a, i2, a, f8.1, a, i2)')  &
         year,',',Month(doy),',',biome,',',tree_density,',',type_grass
   
!*** 2nd line (Carbon strage & flux)
   !Sumup carbon properties
   a1 = c_uptake   /Max_loc/Max_loc / 100.0 !carbon uptake   (Mg C/month/ha)
   a2 = c_emission /Max_loc/Max_loc / 100.0 !carbon emission (Mg C/month/ha)
   
   b1 = pool_litter   * C_in_drymass / Max_loc / Max_loc / 100.0 !Litter  (Mg C/ha)
   b2 = pool_som_int  * C_in_drymass / Max_loc / Max_loc / 100.0 !SOM int (Mg C/ha)
   b3 = pool_som_slow * C_in_drymass / Max_loc / Max_loc / 100.0 !SOM slow(Mg C/ha)
   
   !Woody carbon (Mg C/ha)
   c1 = 0.0
   Do no=1, Max_no
   If (tree_exist(no)) then
      c1 = c1 + mass_leaf(no)+mass_trunk(no)+mass_root(no)+mass_stock(no)+mass_available(no)
   End if
   End do
   c1 = c1 * C_in_drymass / Max_loc / Max_loc / 100.0
   
   !Grass carbon (Mg C/ha)
   if (type_grass==3) then
   c2 = 0.9 * (gmass_leaf(1)+gmass_root(1)+gmass_available(1)+gmass_stock(1)) + &
        0.1 * (gmass_leaf(2)+gmass_root(2)+gmass_available(2)+gmass_stock(2))    
   else
   c2 = 0.1 * (gmass_leaf(1)+gmass_root(1)+gmass_available(1)+gmass_stock(1)) + &
        0.9 * (gmass_leaf(2)+gmass_root(2)+gmass_available(2)+gmass_stock(2))    
   end if
   c2 = c2 * C_in_drymass / 100.0
   
   write (Fn, '( 2(f6.1,a), 4(f8.1,a), f6.1 )') &
         a1,',',a2,',',b1,',',b2,',',b3,',',c1,',',c2
   
!*** 3rd line (Water flux)
   write (Fn, '( f8.2, a, f8.2, a, f8.2, a, f8.2, a, f8.2 )') &
      sum(  prec_RunningRecord(1:Day_of_Month(doy))),',', &
      sum(hyd_ro_RunningRecord(1:Day_of_Month(doy))),',', &
      sum(hyd_ic_RunningRecord(1:Day_of_Month(doy))),',', &
      sum(hyd_ev_RunningRecord(1:Day_of_Month(doy))),',', &
      sum(hyd_tr_RunningRecord(1:Day_of_Month(doy)))       
   
!*** 4th line ~ (for each PFT)
   !Sumup woody biomass (Mg C / ha)
   !  Reset variables
   c_leaf     (:) = 0.0
   c_trunk    (:) = 0.0
   c_root     (:) = 0.0
   c_stock    (:) = 0.0
   c_available(:) = 0.0
   
   !  Woody PFTs
   Do no=1, Max_no
   If (tree_exist(no)) then
      p = pft(no)
      c_leaf     (p) = c_leaf     (p) + mass_leaf(no)
      c_trunk    (p) = c_trunk    (p) + mass_trunk(no)
      c_root     (p) = c_root     (p) + mass_root(no)
      c_stock    (p) = c_stock    (p) + mass_stock(no)
      c_available(p) = c_available(p) + mass_available(no)
   End if
   End do
   
   x = C_in_drymass / Max_loc / Max_loc / 100.0
   c_leaf     (:) = c_leaf     (:) * x
   c_trunk    (:) = c_trunk    (:) * x
   c_root     (:) = c_root     (:) * x
   c_stock    (:) = c_stock    (:) * x
   c_available(:) = c_available(:) * x
   
   !Sunup grass biomass (Mg C / ha)
   x = C_in_drymass / 100.0
   if (type_grass ==3) then
      c_leaf     (C3g_no) = gmass_leaf     (1) * x * 0.9
      c_trunk    (C3g_no) = 0.0                         
      c_root     (C3g_no) = gmass_root     (1) * x * 0.9
      c_stock    (C3g_no) = gmass_stock    (1) * x * 0.9
      c_available(C3g_no) = gmass_available(1) * x * 0.9
      
      c_leaf     (C4g_no) = gmass_leaf     (2) * x * 0.1
      c_trunk    (C4g_no) = 0.0                         
      c_root     (C4g_no) = gmass_root     (2) * x * 0.1
      c_stock    (C4g_no) = gmass_stock    (2) * x * 0.1
      c_available(C4g_no) = gmass_available(2) * x * 0.1
   else
      c_leaf     (C3g_no) = gmass_leaf     (1) * x * 0.1
      c_trunk    (C3g_no) = 0.0                         
      c_root     (C3g_no) = gmass_root     (1) * x * 0.1
      c_stock    (C3g_no) = gmass_stock    (1) * x * 0.1
      c_available(C3g_no) = gmass_available(1) * x * 0.1
      
      c_leaf     (C4g_no) = gmass_leaf     (2) * x * 0.9
      c_trunk    (C4g_no) = 0.0                         
      c_root     (C4g_no) = gmass_root     (2) * x * 0.9
      c_stock    (C4g_no) = gmass_stock    (2) * x * 0.9
      c_available(C4g_no) = gmass_available(2) * x * 0.9
   endif
   
   DO p=1, PFT_no
   if (pft_exist(p)) then
      write (Fn,'( 7(f9.4,a) )') &
      gpp_month(p) * C_in_drymass / Max_loc / Max_loc / 100.0,',', &
      npp_month(p) * C_in_drymass / Max_loc / Max_loc / 100.0,',', &
      c_leaf(p),',',c_trunk(p),',',c_root(p),',',c_stock(p),',',c_available(p)
   endif
   END DO
   
END IF

!_____________ Write Annual output
IF ( Doy==365 ) then
   
   !Prepare size class distribution for each PFT
   size_dist(:,:) = 0.0 !reset
   DO no=1, Max_no
   If (tree_exist(no)) then
      
      p = pft(no)
      i = int(   (100*dbh_heartwood(no) + 100*dbh_sapwood(no)) / Dist_step   )
      
      if (i>=41) then
            size_dist(p,41) = size_dist(p,41) + 1
      elseif (i<1) then
            size_dist(p, 0) = size_dist(p, 0) + 1
      else
            size_dist(p, i) = size_dist(p, i) + 1
      end if
      
   End if
   END DO
   
   !Write size class ditribution
   DO p=1, PFT_no
   if ( (p.ne.c3g_no) .and. (p.ne.c4g_no) ) then
   if ( pft_exist(p) ) then
      do i = 0, 10
      write (Fn,'(i4,a$)') size_dist(p,i),','
      end do
      
      do i = 11, 20
      write (Fn,'(i3,a$)') size_dist(p,i),','
      end do
      
      do i = 21, 41
      write (Fn,'(i2,a$)') size_dist(p,i),','
      end do
      
      write (Fn,*)
   endif
   endif
   END DO
   
END IF

END SUBROUTINE output_for_viewer



!**************************************************************************************************
! Forest status at the every 31 December
!**************************************************************************************************
SUBROUTINE output_annual (Fn)

!_____________ Set variables
!Namespace
   USE data_structure
   USE time_counter
   USE vegi_status_current1
   USE vegi_status_record
   USE grid_status_current1
   implicit none
   
!Arguments
   integer,intent(IN)::Fn   !File I/O number
   
!Local variables
   real    mass_wood      !wood  biomass (g C / m2)
   real    mass_grass     !grass biomass (g C / m2)
   real    mass_soil      !soil  drymass (g C / m2)
   real    gpp_out        !gpp (MgC/ha/year)
   real    npp_out        !npp (MgC/ha/year)
   real    density        !tree density / above 5cm dbh (N/ha)
   real    mass_mean      !mean biomass of tree / above 5cm dbh (kg)
   integer j, no          !for temporal usage
   
!_____________ Prepare output variables
!mass wood
   mass_wood = 0.0
   do no=1, Max_no
   if (tree_exist(no)) then
      mass_wood = mass_wood + &
      mass_leaf(no) + mass_trunk(no) + mass_root(no) + mass_stock(no) + mass_available(no)
   endif
   end do
   mass_wood  = mass_wood * C_in_drymass / Max_loc / Max_loc /100.0
   
!mass grass
   if (type_grass==3) then
    mass_grass = &
     0.9*(gmass_leaf(1)+gmass_root(1)+gmass_stock(1)+gmass_available(1))+ &
     0.1*(gmass_leaf(2)+gmass_root(2)+gmass_stock(2)+gmass_available(2))
   else
    mass_grass = &
     0.1*(gmass_leaf(1)+gmass_root(1)+gmass_stock(1)+gmass_available(1))+ &
     0.9*(gmass_leaf(2)+gmass_root(2)+gmass_stock(2)+gmass_available(2))
   endif
   mass_grass = mass_grass * C_in_drymass / 100.0
   
!mass soil
   mass_soil = pool_litter + pool_som_int + pool_som_slow
   mass_soil = mass_soil      * C_in_drymass * (100/Max_loc) * (100/Max_loc) / (1000*1000)
   
!gpp
   gpp_out  = sum(gpp_annual(:)) * C_in_drymass * (100/Max_loc) * (100/Max_loc) / (1000*1000)
   
!npp
   npp_out  = sum(npp_annual(:)) * C_in_drymass * (100/Max_loc) * (100/Max_loc) / (1000*1000)
   
!density and mass_mean
j = 0
mass_mean=0.0
do no=1, Max_no
if ( tree_exist(no)                        ) then
if ( dbh_heartwood(no) + dbh_sapwood(no) > 0.05 ) then
      j = j+1
      mass_mean = mass_mean + &
      mass_leaf(no) + mass_trunk(no) + mass_root(no) + mass_stock(no) + mass_available(no)
endif
endif
end do
density = real(j) * ( (100.0/Max_loc)**2 )
mass_mean = mass_mean / real(max(1,j)) / 1000.0

!_____________ Write title and data ***
   if (year == 1) then
      write (Fn, *) &
      ' wood  grass   soil   gpp   npp  LAImax_w&g  LAImen_w&g  ccon  type F_tree'
      write (Fn, *) &
      ' |----(MgC/ha)-----| (MgC/ha/yr) |-------(m2/m2)-------|              N/ha'
   end if
   
   write (Fn,'( 3(f6.1,a), 2(f5.1,a), 4(f5.1,a), 1(f6.2,a), 1(i3,a), 1(f7.1,a) )') &
   mass_wood     ,',', &
   mass_grass    ,',', &
   mass_soil     ,',', &
   gpp_out       ,',', &
   npp_out       ,',', &
   lai_max_wood  ,',', &
   lai_max_grass ,',', &
   lai_mean_wood ,',', &
   lai_mean_grass,',', &
   canopy_cond   ,',', &
   biome         ,',', &
   density              
   
END SUBROUTINE output_annual



!**************************************************************************************************
! Output forest 3D structure
!**************************************************************************************************
SUBROUTINE output_forest (Fn)

!_____________ Set variables
!Namespace
   USE data_structure
   USE time_counter
   USE vegi_status_current1
   implicit none
   
!Arguments
   integer,intent(IN)::Fn   !File I/O number
   
!Local variable
   integer count, i
   
!_____________ Main part
!Count tree number
   count = 0
   Do i=1, Max_no
      if ( tree_exist(i) ) count = count +1
   End do
   
!Write data
   write (Fn,'(i4,a1)') count,','
   Do i=1, Max_no
   if (tree_exist(i)) then
      write (Fn,'( 4(f6.1,a), 2(f7.3,a), 2(f7.4,a), i2,a )') &
      bole_x(i)                           ,',',& !1: bole location x
      bole_y(i)                           ,',',& !2: bole location y
      crown_x(i)                          ,',',& !3: crown location x
      crown_y(i)                          ,',',& !4: crown location y
      real(bole(i)) * STEP + 1.3          ,',',& !5: bole height
      real( height(i) - bole(i) ) * STEP  ,',',& !6: foliage height
      dbh_heartwood(i) + dbh_sapwood(i)   ,',',& !7: dbh
      crown_diameter(i)/2.0               ,',',& !8: crown_radius
      pft(i)                              ,','   !9: pft
      
   end if
   End do
   
   !For separate files
   !character :: file_name*32
   !write(file_name,*) year
   !file_name = trim(file_name) // '.txt'
   !open (Fn, file=file_name)
   !close (Fn)
   
END SUBROUTINE output_forest



!**************************************************************************************************
! Output air variables
!**************************************************************************************************
SUBROUTINE output_air (Fn)

!_____________ Set variables
!Namespace
   USE data_structure
   USE time_counter
   USE grid_status_current2
   implicit none
   
!Augments
   integer,intent(IN)::Fn   !File I/O number
   
!_____________ Main part
   !Write title
   if (year == 1 .and. doy==1) then
   write (Fn,*) &
   '  Yr  doy  ap    vps      vp      vpd    dnsa  slope_vps'
   end if
   
   !Write data
   write (Fn,'(2i4, 1f8.1, 5f8.3, f8.2)') &
   year, doy, ap, vp_sat, vp, vpd, dnsa, slope_vps
   
END SUBROUTINE output_air



!**************************************************************************************************
! Output climate variables
!**************************************************************************************************
SUBROUTINE output_climate (Fn, tmp_air, tmp_soil, cloud, prec, humid, wind)

!_____________ Set variables
!Namespace
   USE data_structure
   USE time_counter
   USE grid_status_current2
   implicit none
   
!Arguments
   integer,intent(IN)::Fn     !File I/O number
   
   real,intent(IN)::tmp_air   ! 2m air temperature (Celcius)
   real,intent(IN)::tmp_soil  ! soil temperature at 10 cm  depth (Celcius)
   real,intent(IN)::cloud     ! total cloudness (fraction)
   real,intent(IN)::prec      ! precipitation (mm day-1)
   real,intent(IN)::humid     ! specific humidity (kg kg-1)
   real,intent(IN)::wind      ! wind velocity (m s-1)
   
!_____________ Main part
!Write title
   if (year == 1 .and. doy==1) then
   write (Fn,*) &
   '  yr  doy    air   soil  cloud    prec   humid  vp/vpsat   wind'
   end if
   
!Write data
   write (Fn,'(2i5, 3f7.1, f8.2, f8.3, f8.3, f7.1)') &
   year, doy, tmp_air, tmp_soil, cloud, prec, humid, vp/vp_sat, wind
   
END SUBROUTINE output_climate



!**************************************************************************************************
! Output air variables
!**************************************************************************************************
SUBROUTINE output_radiation (Fn)

!_____________ Set variables
!Namespace
   USE data_structure
   USE time_counter
   USE grid_status_current2
   implicit none
   
!Augments
   integer,intent(IN)::Fn   !File I/O number
   
!_____________ Main part
!Write title
   if (year == 1 .and. doy==1) then
   write (Fn,*) &
   ' Yr doy  s_hgt dlen  rad    par     par_grass'
   end if
   
!Write data
   write (Fn,'(2i4, 2f6.1, 1f7.1, 2f8.1)') &
   year, doy, sl_hgt, dlen, rad, par, par_grass
   
END SUBROUTINE output_radiation



!**************************************************************************************************
! Output net radiation
!**************************************************************************************************
SUBROUTINE output_netradiation (Fn)

!_____________ Set variables
!Namespace
   USE data_structure
   USE time_counter
   USE grid_status_current2
   implicit none
   
!Augments
   integer,intent(IN)::Fn   !File I/O number
   
!_____________ Main part
!Write title
   if (year == 1 .and. doy==1) then
   write (Fn,*) &
   ' Yr doy  s_alb  v_alb  radnet_soil radnet_veg Bowen_ratio'
   end if
   
!Write data
   write (Fn,'(2i4, 2f7.2, 2f10.1, f10.2)') &
   year, doy, albedo_soil, albedo_veg, radnet_soil, radnet_veg, bowen_ratio
   
END SUBROUTINE output_netradiation



!**************************************************************************************************
! Output water status
!**************************************************************************************************
SUBROUTINE output_water (Fn, W_fi, W_wilt, W_sat)

!_____________ Set variables
   USE data_structure
   USE time_counter
   USE grid_status_current1
   USE grid_status_record
   implicit none
   
!Arguments
   integer,intent(IN)::Fn   !File I/O number
   
   real,intent(IN)::W_fi         !filed capacity   (m3/m3, 0.0 -> 1.0)
   real,intent(IN)::W_wilt       !wilting point    (m3/m3, 0.0 -> 1.0)
   real,intent(IN)::W_sat        !saturate point   (m3/m3, 0.0 -> 1.0)
   
!Local valuable
   real a1, a2
   
!_____________ Main part
!Prepare values
   !a1 = pool_w1 / (W_sat * Depth)
   !a2 = pool_w2 / (W_sat * Depth)
   
   a1 = sum(pool_w(1:5)) / 5.0
   a1 = (a1/Depth-W_wilt) / (W_fi-W_wilt)
   a1 = max(0.0, min(1.0, a1))
   
   a2 = sum(pool_w(6:15)) / 10.0
   a2 = (a2/Depth-W_wilt) / (W_fi-W_wilt)
   a2 = max(0.0, min(1.0, a2))
   
!Write title
   if (year == 1 .and. doy==1) then
   write (Fn,*) &
   'Yr doy   snow   pool_w1   pool_w2  stat_w1   stat_w2'
   end if
   
!Write data
   write (Fn,'(2i4, 5f10.2, 2f10.3)') &
   year, doy, pool_snow, sum(pool_w(1:5))/5.0, sum(pool_w(6:15))/10.0, a1, a2
   
END SUBROUTINE output_water



!**************************************************************************************************
! Output carbon flux status
!**************************************************************************************************
SUBROUTINE output_cflux (Fn)

!_____________ Set variables
!Namespace
   USE data_structure
   USE time_counter
   USE vegi_status_current1
   USE grid_status_current1
   USE grid_status_record
   implicit none
   
!Arguments
   integer,intent(IN)::Fn   !File I/O number
   
!Local valiables
   real a1, a2, a3
   real b1, b2, b3
   real c1, c2
   
!_____________ Main part
!Prepare output values
   a1 = c_uptake   /Max_loc/Max_loc / 100.0 !carbon uptake   (Mg C/month/ha)
   a2 = c_emission /Max_loc/Max_loc / 100.0 !carbon emission (Mg C/month/ha)
   a3 = a1 - a2                             !NEP             (Mg C/month/ha)
   
   b1 = pool_litter   * C_in_drymass / Max_loc / Max_loc / 100.0
   b2 = pool_som_int  * C_in_drymass / Max_loc / Max_loc / 100.0
   b3 = pool_som_slow * C_in_drymass / Max_loc / Max_loc / 100.0
   
   c1 = sum(mass_leaf) + sum(mass_trunk) + sum(mass_root) + sum(mass_stock) + sum(mass_available)
   c1 = c1 * C_in_drymass / Max_loc / Max_loc / 100.0
   
   if (type_grass==3) then
   c2 = 0.9 * (gmass_leaf(1)+gmass_root(1)+gmass_available(1)+gmass_stock(1)) + &
        0.1 * (gmass_leaf(2)+gmass_root(2)+gmass_available(2)+gmass_stock(2))    
   else
   c2 = 0.1 * (gmass_leaf(1)+gmass_root(1)+gmass_available(1)+gmass_stock(1)) + &
        0.9 * (gmass_leaf(2)+gmass_root(2)+gmass_available(2)+gmass_stock(2))    
   end if
   c2 = c2 * C_in_drymass / 100.0

!Write title
if (year == 1 .and. Month(doy)==1) then
   write (Fn,*) &
         '       |----- Unit = Mg C ha-1 -------------------------------------->|'
   write (Fn,*) &
         'Yr  mon uptake  emiss    NEP   litter  SOM_int SOM_slow  mass_w mass_g'
end if

!Write data
write (Fn,'( 1(i4,a), 1(i2,a), 3(f6.1,a), 4(f8.1,a), 1(f6.1) )') &
      year       ,',', &
      Month(doy) ,',', &
      a1         ,',', &
      a2         ,',', &
      a3         ,',', &
      b1         ,',', &
      b2         ,',', &
      b3         ,',', &
      c1         ,',', &
      c2                

END SUBROUTINE output_cflux



!**************************************************************************************************
! Output water flux status
!**************************************************************************************************
SUBROUTINE output_wflux (Fn, prec)

!_____________ Set variables
!Namespace
   USE data_structure
   USE time_counter
   USE grid_status_current1
   USE grid_status_record
   implicit none
   
!Arguments
   integer,intent(IN)::Fn   !File I/O number
   real   ,intent(IN)::prec !precipitation (mm/day)
   
!_____________ Main part (monthly)
!Write title
!if (year == 1 .and. Month(doy)==1) then
!   write (Fn,*) &
!         '         |----- Unit = mm month-1 ----------------->|'
!   write (Fn,*) &
!         ' Yr  mon     prec       RO       IC       EV       TR'
!end if
!   
!!Write data
!   write (Fn,'( 1(i5,a), 1(i3,a), 5(f8.2,a) )') &
!      year,',', Month(doy),',', &
!      sum(  prec_RunningRecord(1:Day_of_Month(doy))),',', &
!      sum(hyd_ro_RunningRecord(1:Day_of_Month(doy))),',', &
!      sum(hyd_ic_RunningRecord(1:Day_of_Month(doy))),',', &
!      sum(hyd_ev_RunningRecord(1:Day_of_Month(doy))),',', &
!      sum(hyd_tr_RunningRecord(1:Day_of_Month(doy)))       

!_____________ Main part (daily)
!Write title
if (year == 1 .and. doy==1) then
   write (Fn,*) &
         '         |----- Unit = mm day-1 ----------------->|'
   write (Fn,*) &
         ' Yr  doy     prec       RO       IC       EV       TR'
end if
   
!Write data
   write (Fn,'( i5,a, i3,a, f8.2,a, f8.2,a, f8.2,a, f8.2,a, f8.2 )') &
   year,',', doy,',', prec,',', hyd_ro, ',', hyd_ic,',', hyd_ev,',', hyd_tr
   
END SUBROUTINE output_wflux


!**************************************************************************************************
! Output water flux status
!o͂PFTɉāAR[hύXKv܂
!**************************************************************************************************
SUBROUTINE output_ld_vertical (Fn)

!_____________ Set variables
!Namespace
   USE data_structure
   USE time_counter
   USE vegi_status_current1
   implicit none
   
!Arguments
   integer,intent(IN)::Fn   !File I/O number
   
!Local parameters
   integer,parameter::Vertical_Interval = 10 !number of STEP for each vertical layer for output
   
!Local variables
   integer        no, p, l1, l2
   real           x 
   real,dimension(PFT_no, Max_hgt )                       ::ld1 !sum of leaf area for each step
   real,dimension(PFT_no, int(Max_hgt/Vertical_Interval) )::ld2 !sum of leaf area for each interval
   
!_________________ Sumup leaf area for each tree
   ld1(:,:) = 0.0
   Do no=1, Max_no
   if ( .not. tree_exist(no) ) cycle
      p = pft(no)
      x = la(no) / real(height(no) - bole(no)) !leaf area for each crown disk
      do l1 = bole(no)+1, height(no)
         ld1(p,l1) = ld1(p,l1) + x
      end do
   End do
   ld1(:,:) = ld1(:,:) / Max_loc / Max_loc !adjust unit: (m2 step-1 stand-1) --> (m2 step-1 m-2)
   
!_________________ Convert vertical resolution
   ld2(:,:) = 0.0
   Do p=1, PFT_no
   Do l1=1, Max_hgt
      l2 = int(l1/Vertical_Interval) + 1
      ld2(p,l2) = ld2(p,l2) + ld1(p,l1)
   End do
   End do
   
!_________________ Write Time stamp
   write (Fn, '( 1(i5,a),1(i5,a),1(i7,a) )') year,',',doy,',',counter
   
!_________________ Write distribution
   write (Fn, *)
   Do l2=1, int(Max_hgt/Vertical_Interval) + 1
      !write (Fn,'( f8.5,a,f8.5,a,f8.5,a,f8.5 )') &
      !      ( ld2(1,l2),',',ld2(2,l2),',',ld2(3,l2),',',ld2(4,l2) )
      
      write (Fn,'(f8.5)') ld2(10,l2)
      
   End do
   
END SUBROUTINE output_ld_vertical



!**************************************************************************************************
! Output grass
!**************************************************************************************************
SUBROUTINE output_grass (Fn)

!_____________ Set variables
!Namaspace
   USE data_structure
   USE time_counter
   USE vegi_status_current1
   USE grid_status_current1
   implicit none
   
!Arguments
   integer,intent(IN)::Fn   !File I/O number
   
!Local variable
   real      a1, a2
   character phenology_symbol_c3, phenology_symbol_c4
   real      mass_f_ave, mass_r_ave, mass_stock_ave
   real      mass_total_ave, mass_soil_ave, lai_ave, lai_opt_ave
   
!_________________ set phenology_symbol
   phenology_symbol_c3='-' ; if (phenology(C3g_no)) phenology_symbol_c3='*'
   phenology_symbol_c4='-' ; if (phenology(C4g_no)) phenology_symbol_c4='*'
   
!_________________ prepare output variables
   a1 = gmass_leaf(1) + gmass_root(1) + gmass_available(1) + gmass_stock(1)
   a2 = gmass_leaf(2) + gmass_root(2) + gmass_available(2) + gmass_stock(2)
   
if (type_grass==3) then
   mass_total_ave = 0.9*a1              + 0.1*a2
   mass_f_ave     = 0.9*gmass_leaf(1)   + 0.1*gmass_leaf(2)
   mass_r_ave     = 0.9*gmass_root(1)   + 0.1*gmass_root(2)
   mass_stock_ave = 0.9*gmass_stock(1)  + 0.1*gmass_stock(2)
   lai_ave        = 0.9*lai_grass(1)    + 0.1*lai_grass(2)
   lai_opt_ave    = 0.9*lai_opt_grass(1)+ 0.1*lai_opt_grass(2)
else
   mass_total_ave = 0.1*a1              + 0.9*a2
   mass_f_ave     = 0.1*gmass_leaf(1)   + 0.9*gmass_leaf(2)
   mass_r_ave     = 0.1*gmass_root(1)   + 0.9*gmass_root(2)
   mass_stock_ave = 0.1*gmass_stock(1)  + 0.9*gmass_stock(2)
   lai_ave        = 0.1*lai_grass(1)    + 0.9*lai_grass(2)
   lai_opt_ave    = 0.1*lai_opt_grass(1)+ 0.9*lai_opt_grass(2)
end if
   
   mass_total_ave = C_in_drymass * mass_total_ave
   mass_soil_ave  = C_in_drymass * (pool_litter+pool_som_int+pool_som_slow) / Max_loc / Max_loc
   
!_________________ Write title
   if (year==1 .and. doy==1) then
   write (Fn,*) 'Yr doy pt C3   F    R    S  lai lai_o  C4   F    R    S  lai lai_o'
   end if
   
!_________________ Write data
   write (Fn,'( i3 , i4 , i3 , 2(a3, 3f5.0, 2f5.1) )') &
   year, doy, type_grass,  &
   
   phenology_symbol_c3, gmass_leaf(1), gmass_root(1), gmass_stock(1), &
   lai_grass(1), lai_opt_grass(1), &
   
   phenology_symbol_c4, gmass_leaf(2), gmass_root(2), gmass_stock(2), &
   lai_grass(2), lai_opt_grass(2)
   
END SUBROUTINE output_grass



!**************************************************************************************************
! Biomass composition
!**************************************************************************************************
SUBROUTINE output_biomass (Fn)

!_____________ Set variables
!Namespace
   USE data_structure
   USE vegi_status_current1
   implicit none
   
!Arguments
   integer,intent(IN)::Fn   !File I/O number
   
!Local variables
   real,dimension(PFT_no)::biomass !biomass for each PFT (g C / m2)
   integer                 no      !for loop counter
   real                    x, y    !for gengeral usage
   
!_____________ Main part
!reset output variables
   biomass(:)=0.0
   
!woody biomass (g dm / stand)
   Do no=1, Max_no
   If (tree_exist(no)) then
      biomass(pft(no)) = biomass(pft(no))+&
      mass_leaf(no)+mass_trunk(no)+mass_root(no)+mass_stock(no)+mass_available(no)
   End if
   End do
   
!grass biomass (g dm / stand)
   x = gmass_leaf(1) + gmass_root(1) + gmass_stock(1) + gmass_available(1)
   y = gmass_leaf(2) + gmass_root(2) + gmass_stock(2) + gmass_available(2)
   
   if (type_grass==3) then
      biomass(C3g_no) = 0.9 * Max_loc * Max_loc * x
      biomass(C4g_no) = 0.1 * Max_loc * Max_loc * y
   else
      biomass(C3g_no) = 0.1 * Max_loc * Max_loc * x
      biomass(C4g_no) = 0.9 * Max_loc * Max_loc * y
   endif
   
!adjust unit ( g dm / stand ---> Mg C / ha )
   biomass(:) = biomass(:) * C_in_drymass / Max_loc / Max_loc / 100.0
   
!write title and data
   write (Fn,'( 13(f6.1,1x) )') biomass(:)
   
END SUBROUTINE output_biomass



!**************************************************************************************************
! Biomass composition
!**************************************************************************************************
SUBROUTINE output_lai(Fn)

!_____________ Set variables
!Namespace
   USE data_structure
   USE vegi_status_current1
   implicit none
   
!Arguments
   integer,intent(IN)::Fn   !File I/O number
   
!Local variables
   real,dimension(PFT_no)::lai  !lai for each PFT (g C / m2)
   integer                 no, p
   
!_____________ Main part
!Reset output variables
   lai(:)=0.0
   
!For woody PFTs
   Do no=1, Max_no
   If (tree_exist(no)) then
      p = pft(no)
      lai(p) = lai(p) + la(no)
   End if
   End do
   lai(:) = lai(:) / Max_loc / Max_loc !adjust unit
   
!For grass PFTs
   lai(C3g_no) = lai_grass(1)
   lai(C4g_no) = lai_grass(2)
   
!Write title and data
   write (Fn,'( 13(f4.1,1x) )') lai(:)
   
END SUBROUTINE output_lai



!*************************************************************************************************
! output file maker (for global grid) (called @ the end of each month)
!*************************************************************************************************
SUBROUTINE output_global (Fn)

!_____________ Set variables
!Namespace
   USE data_structure
   USE time_counter
   USE vegi_status_current1
   USE vegi_status_record
   USE grid_status_current1
   USE grid_status_current2
   USE grid_status_record
   implicit none
   
!Arguments
   integer,intent(IN)::Fn   !File I/O number
   
!Local variables
   !for output variables
   real woody_carbon, grass_carbon, som1, som2, som3 !(kg C / m2)
   real gpp_out, npp_out, nep_out                    !(kg C / m2 / month)
   real mean_woody_mass      !(g C / tree)
   real tree_density         !(N / ha)
   real woody_lai, grass_lai !(m2/m2)
   
   integer  no, i
   real     x
   
!_____________ Prepare output variables
   !common procedure
   x = 0.0 !sum of tree biomass (g dm)
   i = 0   !sum of tree number        
   do no=1, Max_no
   if (tree_exist(no)) then
      x = x + mass_leaf(no)+mass_trunk(no)+mass_root(no)+mass_stock(no)+mass_available(no)
      i = i + 1
   endif
   enddo
   
   !tree_density (N / ha)
   tree_density = 10000.0 * real(i) / Max_loc / Max_loc
   
   !mean_woody_mass (kg C / tree)
   mean_woody_mass = x * C_in_drymass / max(1.0, real(i)) / 1000.0
   
   !woody_carbon (kg C / m2)
   woody_carbon = x * C_in_drymass / Max_loc / Max_loc / 1000.0
   
   !grass_carbon (kg C / m2)
   if (type_grass==3) then
     grass_carbon = &
     0.9*(gmass_leaf(1)+gmass_root(1)+gmass_stock(1)+gmass_available(1))+ &
     0.1*(gmass_leaf(2)+gmass_root(2)+gmass_stock(2)+gmass_available(2))
   else
     grass_carbon = &
     0.1*(gmass_leaf(1)+gmass_root(1)+gmass_stock(1)+gmass_available(1))+ &
     0.9*(gmass_leaf(2)+gmass_root(2)+gmass_stock(2)+gmass_available(2))
   endif
   grass_carbon = grass_carbon * C_in_drymass / 1000.0
   
   !soil_carbon (kg C / m2)
   som1 = pool_litter   * C_in_drymass / Max_loc / Max_loc / 1000.0
   som2 = pool_som_int  * C_in_drymass / Max_loc / Max_loc / 1000.0
   som3 = pool_som_slow * C_in_drymass / Max_loc / Max_loc / 1000.0
   
   !GPP (kg C / m2 / month)
   gpp_out = sum(gpp_month) * C_in_drymass / Max_loc / Max_loc / 1000.0
   
   !NPP (kg C / m2 / month)
   npp_out = sum(npp_month) * C_in_drymass / Max_loc / Max_loc / 1000.0
   
   !NEP (kg C / m2 / month)
   nep_out = (c_uptake-c_emission) / Max_loc / Max_loc / 1000.0
   
   !Tree LAI (m2/m2)
   woody_lai = sum(la) / Max_loc / Max_loc
   
   !Grass LAI (m2/m2)
   if (type_grass==3) then
     grass_lai = 0.9 * lai_grass(1) + 0.1 * lai_grass(2)
   else
     grass_lai = 0.1 * lai_grass(1) + 0.9 * lai_grass(2)
   endif
   
!_____________ Write output-data
write (Fn,'( i2, 5(1x,f7.2), 3(1x,f9.1), 3(1x,f8.3), 1(1x,f6.1), 2(1x,f4.1), 4(1x,f6.1), 1x, f6.0, 1x, f6.2 )') &
   biome            , & !1: Biome no (classfication)
   
   woody_carbon     , & !2: Carbon in Woody biomass [kg C / m2]
   grass_carbon     , & !3: Carbon in Grass biomass [kg C / m2]
   som1             , & !4: Carbon in litter        [kg C / m2]
   som2             , & !5: Carbon in som_int       [kg C / m2]
   som3             , & !6: Carbon in som_slow      [kg C / m2]
   
   sum(pool_w(1: 5)), & !7: Water in soil layer 1 [mm]
   sum(pool_w(6:15)), & !8: Water in soil layer 2 [mm]
   pool_snow        , & !9: Water in snow         [mm]
   
   gpp_out          , & !10: GPP [kg C / m2 / month]
   npp_out          , & !11: NPP [kg C / m2 / month]
   nep_out          , & !12: NEP [kg C / m2 / month]
   
   mean_woody_mass  , & !13: mean_woody_mass   [kg C / tree]
   woody_lai        , & !14: LAI of woody PFTs [m2/m2]
   grass_lai        , & !15: LAI of grass PFTs [m2/m2]
   sum(hyd_ro_RunningRecord(1:Day_of_Month(doy))),',', & !16: runoff        [mm/month]
   sum(hyd_ic_RunningRecord(1:Day_of_Month(doy))),',', & !17: interception  [mm/month]
   sum(hyd_ev_RunningRecord(1:Day_of_Month(doy))),',', & !18: evaporation   [mm/month]
   sum(hyd_tr_RunningRecord(1:Day_of_Month(doy))),',', & !19: transpiration [mm/month]
   tree_density     , & !20: tree_density  [N / ha]
   
   canopy_cond          !21: monthly stomatal conductance [mol H2O m-2 s-1]
   
END SUBROUTINE output_global
